==> ogre-next-2.3.3-1-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/_ogre_vulkan_delayed_funcs_8h.js <==
var _ogre_vulkan_delayed_funcs_8h =
[
    [ "Ogre::VulkanDelayed_vkDestroyBufferView", "class_ogre_1_1_vulkan_delayed__vk_destroy_buffer_view.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_buffer_view" ],
    [ "Ogre::VulkanDelayed_vkDestroyFramebuffer", "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer" ],
    [ "Ogre::VulkanDelayed_vkDestroyImage", "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_image" ],
    [ "Ogre::VulkanDelayed_vkDestroyImageView", "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view" ],
    [ "Ogre::VulkanDelayed_vkDestroyPipeline", "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline" ],
    [ "Ogre::VulkanDelayed_vkDestroyRenderPass", "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass" ],
    [ "Ogre::VulkanDelayed_vkDestroySampler", "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler" ],
    [ "Ogre::VulkanDelayed_vkDestroyShaderModule", "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module" ],
    [ "Ogre::VulkanDelayedFuncBase", "class_ogre_1_1_vulkan_delayed_func_base.html", "class_ogre_1_1_vulkan_delayed_func_base" ],
    [ "delayed_vkDestroyBufferView", "_ogre_vulkan_delayed_funcs_8h.html#ad937c7bfa1ff0fc354523f4629fa20a7", null ],
    [ "delayed_vkDestroyFramebuffer", "_ogre_vulkan_delayed_funcs_8h.html#a01b113f08c88f30467e8c76d8496ceea", null ],
    [ "delayed_vkDestroyImage", "_ogre_vulkan_delayed_funcs_8h.html#a7de04fd70ba4d126cbc0fe7934887186", null ],
    [ "delayed_vkDestroyImageView", "_ogre_vulkan_delayed_funcs_8h.html#a384a85abe4c776359b5b4cf2771af367", null ],
    [ "delayed_vkDestroyPipeline", "_ogre_vulkan_delayed_funcs_8h.html#a8159a3c5d756ca7ee2e1dfa203498585", null ],
    [ "delayed_vkDestroyRenderPass", "_ogre_vulkan_delayed_funcs_8h.html#afa2bb027d1c17f8e5600ab0a73455ebd", null ],
    [ "delayed_vkDestroySampler", "_ogre_vulkan_delayed_funcs_8h.html#a472ecba1ddd158f3f4b0035b5237f5f9", null ],
    [ "delayed_vkDestroyShaderModule", "_ogre_vulkan_delayed_funcs_8h.html#ab8c28303f04f47a222edfd79479ca279", null ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/_ogre_vulkan_delayed_funcs_8h.js <==
var _ogre_vulkan_delayed_funcs_8h =
[
    [ "Ogre::VulkanDelayed_vkDestroyBufferView", "class_ogre_1_1_vulkan_delayed__vk_destroy_buffer_view.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_buffer_view" ],
    [ "Ogre::VulkanDelayed_vkDestroyFramebuffer", "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer" ],
    [ "Ogre::VulkanDelayed_vkDestroyImage", "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_image" ],
    [ "Ogre::VulkanDelayed_vkDestroyImageView", "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view" ],
    [ "Ogre::VulkanDelayed_vkDestroyPipeline", "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline" ],
    [ "Ogre::VulkanDelayed_vkDestroyRenderPass", "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass" ],
    [ "Ogre::VulkanDelayed_vkDestroySampler", "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler" ],
    [ "Ogre::VulkanDelayed_vkDestroyShaderModule", "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html", "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module" ],
    [ "Ogre::VulkanDelayedFuncBase", "class_ogre_1_1_vulkan_delayed_func_base.html", "class_ogre_1_1_vulkan_delayed_func_base" ],
    [ "Ogre::delayed_vkDestroyBufferView", "namespace_ogre.html#ad937c7bfa1ff0fc354523f4629fa20a7", null ],
    [ "Ogre::delayed_vkDestroyFramebuffer", "namespace_ogre.html#a01b113f08c88f30467e8c76d8496ceea", null ],
    [ "Ogre::delayed_vkDestroyImage", "namespace_ogre.html#a7de04fd70ba4d126cbc0fe7934887186", null ],
    [ "Ogre::delayed_vkDestroyImageView", "namespace_ogre.html#a384a85abe4c776359b5b4cf2771af367", null ],
    [ "Ogre::delayed_vkDestroyPipeline", "namespace_ogre.html#a8159a3c5d756ca7ee2e1dfa203498585", null ],
    [ "Ogre::delayed_vkDestroyRenderPass", "namespace_ogre.html#afa2bb027d1c17f8e5600ab0a73455ebd", null ],
    [ "Ogre::delayed_vkDestroySampler", "namespace_ogre.html#a472ecba1ddd158f3f4b0035b5237f5f9", null ],
    [ "Ogre::delayed_vkDestroyShaderModule", "namespace_ogre.html#ab8c28303f04f47a222edfd79479ca279", null ]
];
